==============================
Models Optics
==============================

Optical Element
-------------------

.. autoclass:: exorad.models.optics.opticalElement.OpticalElement
    :members:
    :undoc-members:
    :show-inheritance:

Optical path
-----------------

.. autoclass:: exorad.models.optics.opticalPath.OpticalPath
    :members:
    :undoc-members:
    :show-inheritance:

Instrument radiance
--------------------

.. autoclass:: exorad.models.optics.opticalPath.InstRadiance
    :members:
    :undoc-members:
    :show-inheritance:


Surface radiance
-----------------

.. automodule:: exorad.models.optics.opticalPath.surface_radiance
